# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Region(object):
    """A region within an artifact where a result was detected."""

    byte_length = attr.ib(default=None)
    byte_offset = attr.ib(default=-1)
    char_length = attr.ib(default=None)
    char_offset = attr.ib(default=-1)
    end_column = attr.ib(default=None)
    end_line = attr.ib(default=None)
    message = attr.ib(default=None)
    properties = attr.ib(default=None)
    snippet = attr.ib(default=None)
    source_language = attr.ib(default=None)
    start_column = attr.ib(default=None)
    start_line = attr.ib(default=None)
