# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class GraphTraversal(object):
    """Represents a path through a graph."""

    description = attr.ib(default=None)
    edge_traversals = attr.ib(default=None)
    immutable_state = attr.ib(default=None)
    initial_state = attr.ib(default=None)
    properties = attr.ib(default=None)
    result_graph_index = attr.ib(default=-1)
    run_graph_index = attr.ib(default=-1)
