# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Run(object):
    """Describes a single run of an analysis tool, and contains the reported output of that run."""

    tool = attr.ib()
    addresses = attr.ib(default=None)
    artifacts = attr.ib(default=None)
    automation_details = attr.ib(default=None)
    baseline_guid = attr.ib(default=None)
    column_kind = attr.ib(default=None)
    conversion = attr.ib(default=None)
    default_encoding = attr.ib(default=None)
    default_source_language = attr.ib(default=None)
    external_property_file_references = attr.ib(default=None)
    graphs = attr.ib(default=None)
    invocations = attr.ib(default=None)
    language = attr.ib(default="en-US")
    logical_locations = attr.ib(default=None)
    newline_sequences = attr.ib(default=['\r\n', '\n'])
    original_uri_base_ids = attr.ib(default=None)
    policies = attr.ib(default=None)
    properties = attr.ib(default=None)
    redaction_tokens = attr.ib(default=None)
    results = attr.ib(default=None)
    run_aggregates = attr.ib(default=None)
    special_locations = attr.ib(default=None)
    taxonomies = attr.ib(default=None)
    thread_flow_locations = attr.ib(default=None)
    translations = attr.ib(default=None)
    version_control_provenance = attr.ib(default=None)
    web_requests = attr.ib(default=None)
    web_responses = attr.ib(default=None)
