# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Suppression(object):
    """A suppression that is relevant to a result."""

    kind = attr.ib()
    guid = attr.ib(default=None)
    justification = attr.ib(default=None)
    location = attr.ib(default=None)
    properties = attr.ib(default=None)
    state = attr.ib(default=None)
