# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Artifact(object):
    """A single artifact. In some cases, this artifact might be nested within another artifact."""

    contents = attr.ib(default=None)
    description = attr.ib(default=None)
    encoding = attr.ib(default=None)
    hashes = attr.ib(default=None)
    last_modified_time_utc = attr.ib(default=None)
    length = attr.ib(default=-1)
    location = attr.ib(default=None)
    mime_type = attr.ib(default=None)
    offset = attr.ib(default=None)
    parent_index = attr.ib(default=-1)
    properties = attr.ib(default=None)
    roles = attr.ib(default=None)
    source_language = attr.ib(default=None)
