# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ExternalPropertyFileReferences(object):
    """References to external property files that should be inlined with the content of a root log file."""

    addresses = attr.ib(default=None)
    artifacts = attr.ib(default=None)
    conversion = attr.ib(default=None)
    driver = attr.ib(default=None)
    extensions = attr.ib(default=None)
    externalized_properties = attr.ib(default=None)
    graphs = attr.ib(default=None)
    invocations = attr.ib(default=None)
    logical_locations = attr.ib(default=None)
    policies = attr.ib(default=None)
    properties = attr.ib(default=None)
    results = attr.ib(default=None)
    taxonomies = attr.ib(default=None)
    thread_flow_locations = attr.ib(default=None)
    translations = attr.ib(default=None)
    web_requests = attr.ib(default=None)
    web_responses = attr.ib(default=None)
