# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class TranslationMetadata(object):
    """Provides additional metadata related to translation."""

    name = attr.ib()
    download_uri = attr.ib(default=None)
    full_description = attr.ib(default=None)
    full_name = attr.ib(default=None)
    information_uri = attr.ib(default=None)
    properties = attr.ib(default=None)
    short_description = attr.ib(default=None)
