# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ResultProvenance(object):
    """Contains information about how and when a result was detected."""

    conversion_sources = attr.ib(default=None)
    first_detection_run_guid = attr.ib(default=None)
    first_detection_time_utc = attr.ib(default=None)
    invocation_index = attr.ib(default=-1)
    last_detection_run_guid = attr.ib(default=None)
    last_detection_time_utc = attr.ib(default=None)
    properties = attr.ib(default=None)
