# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class WebRequest(object):
    """Describes an HTTP request."""

    body = attr.ib(default=None)
    headers = attr.ib(default=None)
    index = attr.ib(default=-1)
    method = attr.ib(default=None)
    parameters = attr.ib(default=None)
    properties = attr.ib(default=None)
    protocol = attr.ib(default=None)
    target = attr.ib(default=None)
    version = attr.ib(default=None)
