# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Address(object):
    """A physical or virtual address, or a range of addresses, in an 'addressable region' (memory or a binary file)."""

    absolute_address = attr.ib(default=-1)
    fully_qualified_name = attr.ib(default=None)
    index = attr.ib(default=-1)
    kind = attr.ib(default=None)
    length = attr.ib(default=None)
    name = attr.ib(default=None)
    offset_from_parent = attr.ib(default=None)
    parent_index = attr.ib(default=-1)
    properties = attr.ib(default=None)
    relative_address = attr.ib(default=None)
