# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Rectangle(object):
    """An area within an image."""

    bottom = attr.ib(default=None)
    left = attr.ib(default=None)
    message = attr.ib(default=None)
    properties = attr.ib(default=None)
    right = attr.ib(default=None)
    top = attr.ib(default=None)
