# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Node(object):
    """Represents a node in a graph."""

    id = attr.ib()
    children = attr.ib(default=None)
    label = attr.ib(default=None)
    location = attr.ib(default=None)
    properties = attr.ib(default=None)
