# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ToolComponent(object):
    """A component, such as a plug-in or the driver, of the analysis tool that was run."""

    name = attr.ib()
    associated_component = attr.ib(default=None)
    contents = attr.ib(default=['localizedData', 'nonLocalizedData'])
    dotted_quad_file_version = attr.ib(default=None)
    download_uri = attr.ib(default=None)
    full_description = attr.ib(default=None)
    full_name = attr.ib(default=None)
    global_message_strings = attr.ib(default=None)
    guid = attr.ib(default=None)
    information_uri = attr.ib(default=None)
    is_comprehensive = attr.ib(default=None)
    language = attr.ib(default="en-US")
    localized_data_semantic_version = attr.ib(default=None)
    locations = attr.ib(default=None)
    minimum_required_localized_data_semantic_version = attr.ib(default=None)
    notifications = attr.ib(default=None)
    organization = attr.ib(default=None)
    product = attr.ib(default=None)
    product_suite = attr.ib(default=None)
    properties = attr.ib(default=None)
    release_date_utc = attr.ib(default=None)
    rules = attr.ib(default=None)
    semantic_version = attr.ib(default=None)
    short_description = attr.ib(default=None)
    supported_taxonomies = attr.ib(default=None)
    taxa = attr.ib(default=None)
    translation_metadata = attr.ib(default=None)
    version = attr.ib(default=None)
