# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Result(object):
    """A result produced by an analysis tool."""

    message = attr.ib()
    analysis_target = attr.ib(default=None)
    attachments = attr.ib(default=None)
    baseline_state = attr.ib(default=None)
    code_flows = attr.ib(default=None)
    correlation_guid = attr.ib(default=None)
    fingerprints = attr.ib(default=None)
    fixes = attr.ib(default=None)
    graph_traversals = attr.ib(default=None)
    graphs = attr.ib(default=None)
    guid = attr.ib(default=None)
    hosted_viewer_uri = attr.ib(default=None)
    kind = attr.ib(default="fail")
    level = attr.ib(default="warning")
    locations = attr.ib(default=None)
    occurrence_count = attr.ib(default=None)
    partial_fingerprints = attr.ib(default=None)
    properties = attr.ib(default=None)
    provenance = attr.ib(default=None)
    rank = attr.ib(default=-1.0)
    related_locations = attr.ib(default=None)
    rule = attr.ib(default=None)
    rule_id = attr.ib(default=None)
    rule_index = attr.ib(default=-1)
    stacks = attr.ib(default=None)
    suppressions = attr.ib(default=None)
    taxa = attr.ib(default=None)
    web_request = attr.ib(default=None)
    web_response = attr.ib(default=None)
    work_item_uris = attr.ib(default=None)
