# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class LogicalLocation(object):
    """A logical location of a construct that produced a result."""

    decorated_name = attr.ib(default=None)
    fully_qualified_name = attr.ib(default=None)
    index = attr.ib(default=-1)
    kind = attr.ib(default=None)
    name = attr.ib(default=None)
    parent_index = attr.ib(default=-1)
    properties = attr.ib(default=None)
