# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ThreadFlowLocation(object):
    """A location visited by an analysis tool while simulating or monitoring the execution of a program."""

    execution_order = attr.ib(default=-1)
    execution_time_utc = attr.ib(default=None)
    importance = attr.ib(default="important")
    index = attr.ib(default=-1)
    kinds = attr.ib(default=None)
    location = attr.ib(default=None)
    module = attr.ib(default=None)
    nesting_level = attr.ib(default=None)
    properties = attr.ib(default=None)
    stack = attr.ib(default=None)
    state = attr.ib(default=None)
    taxa = attr.ib(default=None)
    web_request = attr.ib(default=None)
    web_response = attr.ib(default=None)
