# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ReportingConfiguration(object):
    """Information about a rule or notification that can be configured at runtime."""

    enabled = attr.ib(default=True)
    level = attr.ib(default="warning")
    parameters = attr.ib(default=None)
    properties = attr.ib(default=None)
    rank = attr.ib(default=-1.0)
