# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Message(object):
    """Encapsulates a message intended to be read by the end user."""

    arguments = attr.ib(default=None)
    id = attr.ib(default=None)
    markdown = attr.ib(default=None)
    properties = attr.ib(default=None)
    text = attr.ib(default=None)
