# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class Tool(object):
    """The analysis tool that was run."""

    driver = attr.ib()
    extensions = attr.ib(default=None)
    properties = attr.ib(default=None)
