# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class WebResponse(object):
    """Describes the response to an HTTP request."""

    body = attr.ib(default=None)
    headers = attr.ib(default=None)
    index = attr.ib(default=-1)
    no_response_received = attr.ib(default=None)
    properties = attr.ib(default=None)
    protocol = attr.ib(default=None)
    reason_phrase = attr.ib(default=None)
    status_code = attr.ib(default=None)
    version = attr.ib(default=None)
