# This file was generated by jschema_to_python version 1.1.0.

import attr


@attr.s
class ReportingDescriptor(object):
    """Metadata that describes a specific report produced by the tool, as part of the analysis it provides or its runtime reporting."""

    id = attr.ib()
    default_configuration = attr.ib(default=None)
    deprecated_guids = attr.ib(default=None)
    deprecated_ids = attr.ib(default=None)
    deprecated_names = attr.ib(default=None)
    full_description = attr.ib(default=None)
    guid = attr.ib(default=None)
    help = attr.ib(default=None)
    help_uri = attr.ib(default=None)
    message_strings = attr.ib(default=None)
    name = attr.ib(default=None)
    properties = attr.ib(default=None)
    relationships = attr.ib(default=None)
    short_description = attr.ib(default=None)
